@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
 ###############
-# dual671_488.py
+# dual671_470.py
 #
 # Copyright David Baddeley, 2012
 # d.baddeley@auckland.ac.nz
@@ -29,9 +29,8 @@ import numpy
 #additional arguments
 taskList = [
 T(-1, scope.turnAllLasersOff),
-T(0, scope.l488.TurnOn),
 T(20, scope.l671.TurnOn),
-T(20, scope.lFibre.TurnOn),
+#T(20, scope.l543.TurnOn),
 T(30, MainFrame.pan_spool.OnBAnalyse, None)
 ]
 
@@ -43,4 +42,4 @@ metaData = [
 
 #must be defined for protocol to be discovered
 PROTOCOL = TaskListProtocol(taskList, metaData)
-PROTOCOL_STACK = ZStackTaskListProtocol(taskList, 20, 100, metaData, randomise = False)
\ No newline at end of file
+PROTOCOL_STACK = ZStackTaskListProtocol(taskList, 20, 100, metaData, randomise = False)
